@@ -66,6 +66,11 @@ static void layout_image_overlay_set(LayoutWindow *lw, gint enable)
 		}
 }
 
+void layout_image_overlay_update(LayoutWindow *lw)
+{
+	if (!lw || !lw->full_screen) return;
+	if (lw->full_screen_overlay_id != -1) image_overlay_update(lw->image, lw->full_screen_overlay_id);
+}
 
 /*
  *----------------------------------------------------------------------------
@@ -98,8 +103,7 @@ static gint layout_image_full_screen_key_press_cb(GtkWidget *widget, GdkEventKey
 	gint x = 0;
 	gint y = 0;
 
-	if ( !(event->state & GDK_CONTROL_MASK) )
-	    switch (event->keyval)
+	switch (event->keyval)
 		{
 		case GDK_Left: case GDK_KP_Left:
 			x -= 1;
@@ -117,6 +121,11 @@ static gint layout_image_full_screen_key_press_cb(GtkWidget *widget, GdkEventKey
 			y += 1;
 			stop_signal = TRUE;
 			break;
+		}
+
+	if ( !(event->state & GDK_CONTROL_MASK) )
+	    switch (event->keyval)
+		{
 		case '+': case '=': case GDK_KP_Add:
 			layout_image_zoom_adjust(lw, get_zoom_increment());
 			break;
@@ -273,7 +282,10 @@ static gint layout_image_full_screen_key_press_cb(GtkWidget *widget, GdkEventKey
 			}
 		if (n != -1)
 			{
-			layout_image_full_screen_stop(lw);
+			if (!editor_window_flag_set(n))
+				{
+				layout_image_full_screen_stop(lw);
+				}
 			start_editor_from_file(n, layout_image_get_path(lw));
 			}
 		}
@@ -559,8 +571,10 @@ static void li_pop_menu_edit_cb(GtkWidget *widget, gpointer data)
 	lw = submenu_item_get_data(widget);
 	n = GPOINTER_TO_INT(data);
 
-	layout_image_full_screen_stop(lw);
-
+	if (!editor_window_flag_set(n))
+		{
+		layout_image_full_screen_stop(lw);
+		}
 	start_editor_from_file(n, layout_image_get_path(lw));
 }
 
@@ -802,7 +816,7 @@ static void layout_image_dnd_receive(GtkWidget *widget, GdkDragContext *context,
 
 		if (info == TARGET_URI_LIST)
 			{
-			list = uri_list_from_text(selection_data->data, TRUE);
+			list = uri_list_from_text((gchar *)selection_data->data, TRUE);
 			source = NULL;
 			info_list = NULL;
 			}
@@ -887,7 +901,7 @@ static void layout_image_dnd_get(GtkWidget *widget, GdkDragContext *context,
 		if (text)
 			{
 			gtk_selection_data_set (selection_data, selection_data->target,
-						8, text, len);
+						8, (guchar *)text, len);
 			g_free(text);
 			}
 		}
@@ -968,14 +982,14 @@ void layout_image_scroll(LayoutWindow *lw, gint x, gint y)
 	image_scroll(lw->image, x, y);
 }
 
-void layout_image_zoom_adjust(LayoutWindow *lw, gfloat increment)
+void layout_image_zoom_adjust(LayoutWindow *lw, gdouble increment)
 {
 	if (!layout_valid(&lw)) return;
 
 	image_zoom_adjust(lw->image, increment);
 }
 
-void layout_image_zoom_set(LayoutWindow *lw, gfloat zoom)
+void layout_image_zoom_set(LayoutWindow *lw, gdouble zoom)
 {
 	if (!layout_valid(&lw)) return;
 
@@ -1388,6 +1402,7 @@ void layout_image_maint_renamed(LayoutWindow *lw, const gchar *source, const gch
 	if (img_path && strcmp(img_path, source) == 0)
 		{
 		image_set_path(lw->image, dest);
+		layout_bars_maint_renamed(lw);
 		}
 }
 
