@@ -23,6 +23,7 @@
 #include "editors.h"
 #include "info.h"
 #include "layout_image.h"
+#include "pixbuf_util.h"
 #include "preferences.h"
 #include "print.h"
 #include "search.h"
@@ -30,6 +31,7 @@
 #include "ui_bookmark.h"
 #include "ui_fileops.h"
 #include "ui_menu.h"
+#include "ui_misc.h"
 #include "ui_tabcomp.h"
 
 #include <gdk/gdkkeysyms.h> /* for keyboard values */
@@ -37,10 +39,6 @@
 #include "icons/icon_thumb.xpm"
 #include "icons/icon_float.xpm"
 
-#include "icons/folder_close.xpm"
-#include "icons/folder_open.xpm"
-#include "icons/folder_deny.xpm"
-
 
 #define MENU_EDIT_ACTION_OFFSET 16
 
@@ -259,7 +257,7 @@ void layout_keyboard_init(LayoutWindow *lw, GtkWidget *window)
  *-----------------------------------------------------------------------------
  */
 
-static void layout_menu_new_window_cb(gpointer data, guint action, GtkWidget *widget)
+static void layout_menu_new_window_cb(GtkAction *action, gpointer data)
 {
 	LayoutWindow *lw = data;
 	LayoutWindow *nw;
@@ -269,118 +267,118 @@ static void layout_menu_new_window_cb(gpointer data, guint action, GtkWidget *wi
 	layout_set_path(nw, layout_get_path(lw));
 }
 
-static void layout_menu_new_cb(gpointer data, guint action, GtkWidget *widget)
+static void layout_menu_new_cb(GtkAction *action, gpointer data)
 {
 	collection_window_new(NULL);
 }
 
-static void layout_menu_open_cb(gpointer data, guint action, GtkWidget *widget)
+static void layout_menu_open_cb(GtkAction *action, gpointer data)
 {
 	collection_dialog_load(NULL);
 }
 
-static void layout_menu_search_cb(gpointer data, guint action, GtkWidget *widget)
+static void layout_menu_search_cb(GtkAction *action, gpointer data)
 {
 	LayoutWindow *lw = data;
 
-	search_new(lw->path, NULL);
+	search_new(lw->path, layout_image_get_path(lw));
 }
 
-static void layout_menu_dupes_cb(gpointer data, guint action, GtkWidget *widget)
+static void layout_menu_dupes_cb(GtkAction *action, gpointer data)
 {
 	dupe_window_new(DUPE_MATCH_NAME);
 }
 
-static void layout_menu_print_cb(gpointer data, guint action, GtkWidget *widget)
+static void layout_menu_print_cb(GtkAction *action, gpointer data)
 {
 	LayoutWindow *lw = data;
 
 	print_window_new(layout_image_get_path(lw), layout_selection_list(lw), layout_list(lw), lw->window);
 }
 
-static void layout_menu_dir_cb(gpointer data, guint action, GtkWidget *widget)
+static void layout_menu_dir_cb(GtkAction *action, gpointer data)
 {
 	LayoutWindow *lw = data;
 
 	file_util_create_dir(lw->path, lw->window);
 }
 
-static void layout_menu_copy_cb(gpointer data, guint action, GtkWidget *widget)
+static void layout_menu_copy_cb(GtkAction *action, gpointer data)
 {
 	LayoutWindow *lw = data;
 
 	file_util_copy(NULL, layout_selection_list(lw), NULL, lw->window);
 }
 
-static void layout_menu_move_cb(gpointer data, guint action, GtkWidget *widget)
+static void layout_menu_move_cb(GtkAction *action, gpointer data)
 {
 	LayoutWindow *lw = data;
 
 	file_util_move(NULL, layout_selection_list(lw), NULL, lw->window);
 }
 
-static void layout_menu_rename_cb(gpointer data, guint action, GtkWidget *widget)
+static void layout_menu_rename_cb(GtkAction *action, gpointer data)
 {
 	LayoutWindow *lw = data;
 
 	file_util_rename(NULL, layout_selection_list(lw), lw->window);
 }
 
-static void layout_menu_delete_cb(gpointer data, guint action, GtkWidget *widget)
+static void layout_menu_delete_cb(GtkAction *action, gpointer data)
 {
 	LayoutWindow *lw = data;
 
 	file_util_delete(NULL, layout_selection_list(lw), lw->window);
 }
 
-static void layout_menu_close_cb(gpointer data, guint action, GtkWidget *widget)
+static void layout_menu_close_cb(GtkAction *action, gpointer data)
 {
 	LayoutWindow *lw = data;
 
 	layout_close(lw);
 }
 
-static void layout_menu_exit_cb(gpointer data, guint action, GtkWidget *widget)
+static void layout_menu_exit_cb(GtkAction *action, gpointer data)
 {
 	exit_gqview();
 }
 
-static void layout_menu_alter_90_cb(gpointer data, guint action, GtkWidget *widget)
+static void layout_menu_alter_90_cb(GtkAction *action, gpointer data)
 {
 	LayoutWindow *lw = data;
 
 	layout_image_alter(lw, ALTER_ROTATE_90);
 }
 
-static void layout_menu_alter_90cc_cb(gpointer data, guint action, GtkWidget *widget)
+static void layout_menu_alter_90cc_cb(GtkAction *action, gpointer data)
 {
 	LayoutWindow *lw = data;
 
 	layout_image_alter(lw, ALTER_ROTATE_90_CC);
 }
 
-static void layout_menu_alter_180_cb(gpointer data, guint action, GtkWidget *widget)
+static void layout_menu_alter_180_cb(GtkAction *action, gpointer data)
 {
 	LayoutWindow *lw = data;
 
 	layout_image_alter(lw, ALTER_ROTATE_180);
 }
 
-static void layout_menu_alter_mirror_cb(gpointer data, guint action, GtkWidget *widget)
+static void layout_menu_alter_mirror_cb(GtkAction *action, gpointer data)
 {
 	LayoutWindow *lw = data;
 
 	layout_image_alter(lw, ALTER_MIRROR);
 }
 
-static void layout_menu_alter_flip_cb(gpointer data, guint action, GtkWidget *widget)
+static void layout_menu_alter_flip_cb(GtkAction *action, gpointer data)
 {
 	LayoutWindow *lw = data;
 
 	layout_image_alter(lw, ALTER_FLIP);
 }
 
-static void layout_menu_info_cb(gpointer data, guint action, GtkWidget *widget)
+static void layout_menu_info_cb(GtkAction *action, gpointer data)
 {
 	LayoutWindow *lw = data;
 	GList *list;
@@ -392,81 +390,80 @@ static void layout_menu_info_cb(gpointer data, guint action, GtkWidget *widget)
 	info_window_new(path, list);
 }
 
-static void layout_menu_select_all_cb(gpointer data, guint action, GtkWidget *widget)
+static void layout_menu_select_all_cb(GtkAction *action, gpointer data)
 {
 	LayoutWindow *lw = data;
 
 	layout_select_all(lw);
 }
 
-static void layout_menu_unselect_all_cb(gpointer data, guint action, GtkWidget *widget)
+static void layout_menu_unselect_all_cb(GtkAction *action, gpointer data)
 {
 	LayoutWindow *lw = data;
 
 	layout_select_none(lw);
 }
 
-static void layout_menu_config_cb(gpointer data, guint action, GtkWidget *widget)
+static void layout_menu_config_cb(GtkAction *action, gpointer data)
 {
 	show_config_window();
 }
 
-static void layout_menu_remove_thumb_cb(gpointer data, guint action, GtkWidget *widget)
+static void layout_menu_remove_thumb_cb(GtkAction *action, gpointer data)
 {
-	cache_maintain_home(FALSE);
+	cache_manager_show();
 }
 
-static void layout_menu_wallpaper_cb(gpointer data, guint action, GtkWidget *widget)
+static void layout_menu_wallpaper_cb(GtkAction *action, gpointer data)
 {
 	LayoutWindow *lw = data;
 
 	layout_image_to_root(lw);
 }
 
-static void layout_menu_zoom_in_cb(gpointer data, guint action, GtkWidget *widget)
+static void layout_menu_zoom_in_cb(GtkAction *action, gpointer data)
 {
 	LayoutWindow *lw = data;
 
 	layout_image_zoom_adjust(lw, get_zoom_increment());
 }
 
-static void layout_menu_zoom_out_cb(gpointer data, guint action, GtkWidget *widget)
+static void layout_menu_zoom_out_cb(GtkAction *action, gpointer data)
 {
 	LayoutWindow *lw = data;
 
 	layout_image_zoom_adjust(lw, -get_zoom_increment());
 }
 
-static void layout_menu_zoom_1_1_cb(gpointer data, guint action, GtkWidget *widget)
+static void layout_menu_zoom_1_1_cb(GtkAction *action, gpointer data)
 {
 	LayoutWindow *lw = data;
 
 	layout_image_zoom_set(lw, 1.0);
 }
 
-static void layout_menu_zoom_fit_cb(gpointer data, guint action, GtkWidget *widget)
+static void layout_menu_zoom_fit_cb(GtkAction *action, gpointer data)
 {
 	LayoutWindow *lw = data;
 
 	layout_image_zoom_set(lw, 0.0);
 }
 
-static void layout_menu_thumb_cb(gpointer data, guint action, GtkWidget *widget)
+static void layout_menu_thumb_cb(GtkToggleAction *action, gpointer data)
 {
 	LayoutWindow *lw = data;
 
-	layout_thumb_set(lw, GTK_CHECK_MENU_ITEM(widget)->active);
+	layout_thumb_set(lw, gtk_toggle_action_get_active(action));
 }
 
-static void layout_menu_list_cb(gpointer data, guint action, GtkWidget *widget)
+static void layout_menu_list_cb(GtkRadioAction *action, GtkRadioAction *current, gpointer data)
 {
 	LayoutWindow *lw = data;
 
-	if (!GTK_CHECK_MENU_ITEM(widget)->active) return;
-
-	layout_views_set(lw, lw->tree_view, FALSE);
+	layout_views_set(lw, lw->tree_view, (gtk_radio_action_get_current_value(action) == 1));
 }
 
+#if 0
 static void layout_menu_icon_cb(gpointer data, guint action, GtkWidget *widget)
 {
 	LayoutWindow *lw = data;
@@ -475,108 +472,109 @@ static void layout_menu_icon_cb(gpointer data, guint action, GtkWidget *widget)
 
 	layout_views_set(lw, lw->tree_view, TRUE);
 }
+#endif
 
-static void layout_menu_tree_cb(gpointer data, guint action, GtkWidget *widget)
+static void layout_menu_tree_cb(GtkToggleAction *action, gpointer data)
 {
 	LayoutWindow *lw = data;
 
-	layout_views_set(lw, GTK_CHECK_MENU_ITEM(widget)->active, lw->icon_view);
+	layout_views_set(lw, gtk_toggle_action_get_active(action), lw->icon_view);
 }
 
-static void layout_menu_full_screen_cb(gpointer data, guint action, GtkWidget *widget)
+static void layout_menu_fullscreen_cb(GtkAction *action, gpointer data)
 {
 	LayoutWindow *lw = data;
 
 	layout_image_full_screen_toggle(lw);
 }
 
-static void layout_menu_refresh_cb(gpointer data, guint action, GtkWidget *widget)
+static void layout_menu_refresh_cb(GtkAction *action, gpointer data)
 {
 	LayoutWindow *lw = data;
 
 	layout_refresh(lw);
 }
 
-static void layout_menu_float_cb(gpointer data, guint action, GtkWidget *widget)
+static void layout_menu_float_cb(GtkToggleAction *action, gpointer data)
 {
 	LayoutWindow *lw = data;
 
-	if (lw->tools_float != GTK_CHECK_MENU_ITEM(widget)->active)
+	if (lw->tools_float != gtk_toggle_action_get_active(action))
 		{
 		layout_tools_float_toggle(lw);
 		}
 }
 
-static void layout_menu_hide_cb(gpointer data, guint action, GtkWidget *widget)
+static void layout_menu_hide_cb(GtkAction *action, gpointer data)
 {
 	LayoutWindow *lw = data;
 
 	layout_tools_hide_toggle(lw);
 }
 
-static void layout_menu_toolbar_cb(gpointer data, guint action, GtkWidget *widget)
+static void layout_menu_toolbar_cb(GtkToggleAction *action, gpointer data)
 {
 	LayoutWindow *lw = data;
 
-	if (lw->toolbar_hidden != GTK_CHECK_MENU_ITEM(widget)->active)
+	if (lw->toolbar_hidden != gtk_toggle_action_get_active(action))
 		{
 		layout_toolbar_toggle(lw);
 		}
 }
 
-static void layout_menu_bar_info_cb(gpointer data, guint action, GtkWidget *widget)
+static void layout_menu_bar_info_cb(GtkToggleAction *action, gpointer data)
 {
 	LayoutWindow *lw = data;
 
-	if (lw->bar_info_enabled != GTK_CHECK_MENU_ITEM(widget)->active)
+	if (lw->bar_info_enabled != gtk_toggle_action_get_active(action))
 		{
 		layout_bar_info_toggle(lw);
 		}
 }
 
-static void layout_menu_bar_exif_cb(gpointer data, guint action, GtkWidget *widget)
+static void layout_menu_bar_exif_cb(GtkToggleAction *action, gpointer data)
 {
 	LayoutWindow *lw = data;
 
-	if (lw->bar_exif_enabled != GTK_CHECK_MENU_ITEM(widget)->active)
+	if (lw->bar_exif_enabled != gtk_toggle_action_get_active(action))
 		{
 		layout_bar_exif_toggle(lw);
 		}
 }
 
-static void layout_menu_bar_sort_cb(gpointer data, guint action, GtkWidget *widget)
+static void layout_menu_bar_sort_cb(GtkToggleAction *action, gpointer data)
 {
 	LayoutWindow *lw = data;
 
-	if (lw->bar_sort_enabled != GTK_CHECK_MENU_ITEM(widget)->active)
+	if (lw->bar_sort_enabled != gtk_toggle_action_get_active(action))
 		{
 		layout_bar_sort_toggle(lw);
 		}
 }
 
-static void layout_menu_slideshow_cb(gpointer data, guint action, GtkWidget *widget)
+static void layout_menu_slideshow_cb(GtkAction *action, gpointer data)
 {
 	LayoutWindow *lw = data;
 
 	layout_image_slideshow_toggle(lw);
 }
 
-static void layout_menu_help_cb(gpointer data, guint action, GtkWidget *widget)
+static void layout_menu_help_cb(GtkAction *action, gpointer data)
 {
 	help_window_show("html_contents");
 }
 
-static void layout_menu_help_keys_cb(gpointer data, guint action, GtkWidget *widget)
+static void layout_menu_help_keys_cb(GtkAction *action, gpointer data)
 {
 	help_window_show("documentation");
 }
 
-static void layout_menu_notes_cb(gpointer data, guint action, GtkWidget *widget)
+static void layout_menu_notes_cb(GtkAction *action, gpointer data)
 {
 	help_window_show("release_notes");
 }
 
-static void layout_menu_about_cb(gpointer data, guint action, GtkWidget *widget)
+static void layout_menu_about_cb(GtkAction *action, gpointer data)
 {
 	show_about_window();
 }
@@ -587,13 +585,13 @@ static void layout_menu_about_cb(gpointer data, guint action, GtkWidget *widget)
  *-----------------------------------------------------------------------------
  */ 
 
-static void layout_menu_edit_cb(gpointer data, guint action, GtkWidget *widget)
+static void layout_menu_edit_cb(GtkAction *action, gpointer data)
 {
 	LayoutWindow *lw = data;
 	GList *list;
 	gint n;
 
-	n = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(widget), "edit_index"));
+	n = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(action), "edit_index"));
 
 	list = layout_selection_list(lw);
 	start_editor_from_path_list(n, list);
@@ -606,16 +604,22 @@ static void layout_menu_edit_update(LayoutWindow *lw)
 
 	/* main edit menu */
 
-	for(i = 0; i < 10; i++)
-		{
-		GtkWidget *item;
+	if (!lw->action_group) return;
 
-		item = gtk_item_factory_get_item_by_action(lw->menu_fact, MENU_EDIT_ACTION_OFFSET + i);
-		g_object_set_data(G_OBJECT(item), "edit_index", GINT_TO_POINTER(i));
+	for (i = 0; i < 10; i++)
+		{
+		gchar *key;
+		GtkAction *action;
+
+		key = g_strdup_printf("Editor%d", i);
+
+		action = gtk_action_group_get_action(lw->action_group, key);
+		g_object_set_data(G_OBJECT(action), "edit_index", GINT_TO_POINTER(i));
 
 		if (editor_command[i] && strlen(editor_command[i]) > 0)
 			{
 			gchar *text;
+
 			if (editor_name[i] && strlen(editor_name[i]) > 0)
 				{
 				text = g_strdup_printf(_("in %s..."), editor_name[i]);
@@ -624,14 +628,17 @@ static void layout_menu_edit_update(LayoutWindow *lw)
 				{
 				text = g_strdup(_("in (unknown)..."));
 				}
-			gtk_label_set_text(GTK_LABEL(GTK_BIN(item)->child), text);
+			g_object_set(action, "label", text,
+					     "sensitive", TRUE, NULL);
 			g_free(text);
-			gtk_widget_show(item);
 			}
 		else
 			{
-			gtk_widget_hide(item);
+			g_object_set(action, "label", _("empty"),
+					     "sensitive", FALSE, NULL);
 			}
+
+		g_free(key);
 		}
 }
 
@@ -680,6 +687,8 @@ static void layout_menu_recent_update(LayoutWindow *lw)
 	GList *list;
 	gint n;
 
+	if (!lw->ui_manager) return;
+
 	list = history_list_get_by_key("recent");
 	n = 0;
 
@@ -699,7 +708,7 @@ static void layout_menu_recent_update(LayoutWindow *lw)
 		menu_item_add(menu, _("Empty"), NULL, NULL);
 		}
 
-	recent = gtk_item_factory_get_item(lw->menu_fact, "/File/Open recent");
+	recent = gtk_ui_manager_get_widget(lw->ui_manager, "/MainMenu/FileMenu/OpenRecent");
 	gtk_menu_item_set_submenu(GTK_MENU_ITEM(recent), menu);
 	gtk_widget_set_sensitive(recent, (n != 0));
 }
@@ -733,113 +742,224 @@ void layout_recent_add_path(const gchar *path)
  *-----------------------------------------------------------------------------
  */ 
 
-static GtkItemFactoryEntry gqview_menu_items[] =
-{
-	{ N_("/_File"),				NULL,		NULL,				0, "<Branch>" },
-	{ N_("/File/tear1"),			NULL,		NULL,				0, "<Tearoff>" },
-	{ N_("/File/New _window"),		NULL, 		layout_menu_new_window_cb,	0, "<StockItem>", GTK_STOCK_NEW },
-	{ N_("/File/_New collection"),		"C",		layout_menu_new_cb,		0, "<StockItem>", GTK_STOCK_INDEX },
-	{ N_("/File/_Open collection..."),	"O",		layout_menu_open_cb,		0, "<StockItem>", GTK_STOCK_OPEN },
-	{ N_("/File/Open _recent"),		NULL,		NULL,				0, NULL },
-	{ N_("/File/sep1"),			NULL,		NULL,				0, "<Separator>" },
-	{ N_("/File/_Search..."),		"F3",		layout_menu_search_cb,		0, "<StockItem>", GTK_STOCK_FIND },
-	{ N_("/File/_Find duplicates..."),	"D",		layout_menu_dupes_cb,		0, "<StockItem>", GTK_STOCK_FIND },
-	{ N_("/File/sep2"),			NULL,		NULL,				0, "<Separator>" },
-	{ N_("/File/_Print..."),		"<shift>P",		layout_menu_print_cb,		0, "<StockItem>", GTK_STOCK_PRINT },
-	{ N_("/File/N_ew folder..."),		"<control>F",	layout_menu_dir_cb,		0, NULL },
-	{ N_("/File/sep3"),			NULL,		NULL,				0, "<Separator>" },
-	{ N_("/File/_Copy..."),			"<control>C",	layout_menu_copy_cb,		0, "<StockItem>", GTK_STOCK_COPY },
-	{ N_("/File/_Move..."),			"<control>M",	layout_menu_move_cb,		0, NULL },
-	{ N_("/File/_Rename..."),		"<control>R",	layout_menu_rename_cb,		0, NULL },
-	{ N_("/File/_Delete..."),		"<control>D",	layout_menu_delete_cb,		0, "<StockItem>", GTK_STOCK_DELETE },
-	{ N_("/File/sep4"),			NULL,		NULL,				0, "<Separator>" },
-	{ N_("/File/C_lose window"),		"<control>W",	layout_menu_close_cb,		0, "<StockItem>", GTK_STOCK_CLOSE },
-	{ N_("/File/E_xit"),			"<control>Q",	layout_menu_exit_cb,		0, "<StockItem>", GTK_STOCK_QUIT },
+#define CB G_CALLBACK
 
-	{ N_("/_Edit"),				NULL,		NULL,				0, "<Branch>" },
-	{ N_("/Edit/tear1"),			NULL,		NULL,				0, "<Tearoff>" },
-	{ N_("/Edit/editor1"),			"<control>1",	layout_menu_edit_cb,		MENU_EDIT_ACTION_OFFSET + 0, NULL },
-	{ N_("/Edit/editor2"),			"<control>2",	layout_menu_edit_cb,		MENU_EDIT_ACTION_OFFSET + 1, NULL },
-	{ N_("/Edit/editor3"),			"<control>3",	layout_menu_edit_cb,		MENU_EDIT_ACTION_OFFSET + 2, NULL },
-	{ N_("/Edit/editor4"),			"<control>4",	layout_menu_edit_cb,		MENU_EDIT_ACTION_OFFSET + 3, NULL },
-	{ N_("/Edit/editor5"),			"<control>5",	layout_menu_edit_cb,		MENU_EDIT_ACTION_OFFSET + 4, NULL },
-	{ N_("/Edit/editor6"),			"<control>6",	layout_menu_edit_cb,		MENU_EDIT_ACTION_OFFSET + 5, NULL },
-	{ N_("/Edit/editor7"),			"<control>7",	layout_menu_edit_cb,		MENU_EDIT_ACTION_OFFSET + 6, NULL },
-	{ N_("/Edit/editor8"),			"<control>8",	layout_menu_edit_cb,		MENU_EDIT_ACTION_OFFSET + 7, NULL },
-	{ N_("/Edit/editor9"),			"<control>9",	layout_menu_edit_cb,		MENU_EDIT_ACTION_OFFSET + 8, NULL },
-	{ N_("/Edit/editor0"),			"<control>0",	layout_menu_edit_cb,		MENU_EDIT_ACTION_OFFSET + 9, NULL},
-	{ N_("/Edit/sep1"),			NULL,		NULL,				0, "<Separator>" },
-	{ N_("/Edit/_Adjust"),			NULL,		NULL,				0, "<Branch>" },
-	{ N_("/Edit/_Properties"),		"<control>P",	layout_menu_info_cb,		0, "<StockItem>", GTK_STOCK_PROPERTIES },
-	{ N_("/Edit/Adjust/tear1"),		NULL,		NULL,				0, "<Tearoff>" },
-	{ N_("/Edit/Adjust/_Rotate clockwise"),		"bracketright",	layout_menu_alter_90_cb,	0, NULL },
-	{ N_("/Edit/Adjust/Rotate _counterclockwise"),	"bracketleft",	layout_menu_alter_90cc_cb,	0, NULL },
-	{ N_("/Edit/Adjust/Rotate 1_80"),	"<shift>R",	layout_menu_alter_180_cb,	0, NULL },
-	{ N_("/Edit/Adjust/_Mirror"),		"<shift>M",	layout_menu_alter_mirror_cb,	0, NULL },
-	{ N_("/Edit/Adjust/_Flip"),		"<shift>F",	layout_menu_alter_flip_cb,	0, NULL },
-	{ N_("/Edit/sep2"),			NULL,		NULL,				0, "<Separator>" },
-	{ N_("/Edit/Select _all"),		"<control>A",	layout_menu_select_all_cb,	0, NULL },
-	{ N_("/Edit/Select _none"),	"<control><shift>A",	layout_menu_unselect_all_cb,	0, NULL },
-	{ N_("/Edit/sep3"),			NULL,		NULL,				0, "<Separator>" },
-	{ N_("/Edit/_Options..."),		"<control>O",	layout_menu_config_cb,		0, "<StockItem>", GTK_STOCK_PREFERENCES },
-	{ N_("/Edit/_Remove old thumbnails"),	NULL,		layout_menu_remove_thumb_cb,	0, NULL },
-	{ N_("/Edit/sep4"),			NULL,		NULL,				0, "<Separator>" },
-	{ N_("/Edit/Set as _wallpaper"),	NULL,		layout_menu_wallpaper_cb,	0, NULL },
+static GtkActionEntry menu_entries[] = {
+  { "FileMenu",		NULL,		N_("_File") },
+  { "EditMenu",		NULL,		N_("_Edit") },
+  { "AdjustMenu",	NULL,		N_("_Adjust") },
+  { "ViewMenu",		NULL,		N_("_View") },
+  { "HelpMenu",		NULL,		N_("_Help") },
 
-	{ N_("/_View"),				NULL,		NULL,				0, "<Branch>" },
-	{ N_("/View/tear1"),			NULL,		NULL,				0, "<Tearoff>" },
-	{ N_("/View/Zoom _in"),			"equal",	layout_menu_zoom_in_cb,		0, "<StockItem>", GTK_STOCK_ZOOM_IN },
-	{ N_("/View/Zoom _out"),		"minus",	layout_menu_zoom_out_cb,	0, "<StockItem>", GTK_STOCK_ZOOM_OUT },
-	{ N_("/View/Zoom _1:1"),		"Z",		layout_menu_zoom_1_1_cb,	0, "<StockItem>", GTK_STOCK_ZOOM_100 },
-	{ N_("/View/_Zoom to fit"),		"X",		layout_menu_zoom_fit_cb,	0, "<StockItem>", GTK_STOCK_ZOOM_FIT },
-	{ N_("/View/sep1"),			NULL,		NULL,				0, "<Separator>" },
+  { "NewWindow",	GTK_STOCK_NEW,	N_("New _window"),	NULL,		NULL,	CB(layout_menu_new_window_cb) },
+  { "NewCollection",	GTK_STOCK_INDEX,N_("_New collection"),	"C",		NULL,	CB(layout_menu_new_cb) },
+  { "OpenCollection",	GTK_STOCK_OPEN,	N_("_Open collection..."),"O",		NULL,	CB(layout_menu_open_cb) },
+  { "OpenRecent",	NULL,		N_("Open _recent") },
+  { "Search",		GTK_STOCK_FIND,	N_("_Search..."),	"F3",		NULL,	CB(layout_menu_search_cb) },
+  { "FindDupes",	GTK_STOCK_FIND,	N_("_Find duplicates..."),"D",		NULL,	CB(layout_menu_dupes_cb) },
+  { "Print",		GTK_STOCK_PRINT,N_("_Print..."),	"<shift>P",	NULL,	CB(layout_menu_print_cb) },
+  { "NewFolder",	NULL,		N_("N_ew folder..."),	"<control>F",	NULL,	CB(layout_menu_dir_cb) },
+  { "Copy",		NULL,		N_("_Copy..."),		"<control>C",	NULL,	CB(layout_menu_copy_cb) },
+  { "Move",		NULL,		N_("_Move..."),		"<control>M",	NULL,	CB(layout_menu_move_cb) },
+  { "Rename",		NULL,		N_("_Rename..."),	"<control>R",	NULL,	CB(layout_menu_rename_cb) },
+  { "Delete",	GTK_STOCK_DELETE,	N_("_Delete..."),	"<control>D",	NULL,	CB(layout_menu_delete_cb) },
+  { "CloseWindow",	GTK_STOCK_CLOSE,N_("C_lose window"),	"<control>W",	NULL,	CB(layout_menu_close_cb) },
+  { "Quit",		GTK_STOCK_QUIT, N_("_Quit"),		"<control>Q",	NULL,	CB(layout_menu_exit_cb) },
 
-	{ N_("/View/_Thumbnails"),		"T",		layout_menu_thumb_cb,		0, "<CheckItem>" },
-	{ N_("/View/_List"),			"<control>L",	layout_menu_list_cb,		0, "<RadioItem>" },
-	{ N_("/View/I_cons"),			"<control>I",	layout_menu_icon_cb,		0, "/View/List" },
+  { "Editor0",		NULL,		"editor0",		"<control>1",	NULL,	CB(layout_menu_edit_cb) },
+  { "Editor1",		NULL,		"editor1",		"<control>2",	NULL,	CB(layout_menu_edit_cb) },
+  { "Editor2",		NULL,		"editor2",		"<control>3",	NULL,	CB(layout_menu_edit_cb) },
+  { "Editor3",		NULL,		"editor3",		"<control>4",	NULL,	CB(layout_menu_edit_cb) },
+  { "Editor4",		NULL,		"editor4",		"<control>5",	NULL,	CB(layout_menu_edit_cb) },
+  { "Editor5",		NULL,		"editor5",		"<control>6",	NULL,	CB(layout_menu_edit_cb) },
+  { "Editor6",		NULL,		"editor6",		"<control>7",	NULL,	CB(layout_menu_edit_cb) },
+  { "Editor7",		NULL,		"editor7",		"<control>8",	NULL,	CB(layout_menu_edit_cb) },
+  { "Editor8",		NULL,		"editor8",		"<control>9",	NULL,	CB(layout_menu_edit_cb) },
+  { "Editor9",		NULL,		"editor9",		"<control>0",	NULL,	CB(layout_menu_edit_cb) },
+  { "RotateCW",		NULL,	N_("_Rotate clockwise"),	"bracketright",	NULL,	CB(layout_menu_alter_90_cb) },
+  { "RotateCCW",	NULL,	N_("Rotate _counterclockwise"),	"bracketleft",	NULL,	CB(layout_menu_alter_90cc_cb) },
+  { "Rotate180",	NULL,		N_("Rotate 1_80"),	"<shift>R",	NULL,	CB(layout_menu_alter_180_cb) },
+  { "Mirror",		NULL,		N_("_Mirror"),		"<shift>M",	NULL,	CB(layout_menu_alter_mirror_cb) },
+  { "Flip",		NULL,		N_("_Flip"),		"<shift>F",	NULL,	CB(layout_menu_alter_flip_cb) },
+  { "Properties",GTK_STOCK_PROPERTIES,	N_("_Properties"),	"<control>P",	NULL,	CB(layout_menu_info_cb) },
+  { "SelectAll",	NULL,		N_("Select _all"),	"<control>A",	NULL,	CB(layout_menu_select_all_cb) },
+  { "SelectNone",	NULL,		N_("Select _none"), "<control><shift>A",NULL,	CB(layout_menu_unselect_all_cb) },
+  { "Preferences",GTK_STOCK_PREFERENCES,N_("P_references..."),	"<control>O",	NULL,	CB(layout_menu_config_cb) },
+  { "Maintenance",	NULL,		N_("_Thumbnail maintenance..."),NULL,	NULL,	CB(layout_menu_remove_thumb_cb) },
+  { "Wallpaper",	NULL,		N_("Set as _wallpaper"),NULL,		NULL,	CB(layout_menu_wallpaper_cb) },
 
-	{ N_("/View/sep2"),			NULL,		NULL,				0, "<Separator>" },
-	{ N_("/View/Tr_ee"),			"<control>T",	layout_menu_tree_cb,		0, "<CheckItem>" },
-	{ N_("/View/F_ull screen"),		"F",		layout_menu_full_screen_cb,	0, NULL },
+  { "ZoomIn",	GTK_STOCK_ZOOM_IN,	N_("Zoom _in"),		"equal",	NULL,	CB(layout_menu_zoom_in_cb) },
+  { "ZoomOut",	GTK_STOCK_ZOOM_OUT,	N_("Zoom _out"),	"minus",	NULL,	CB(layout_menu_zoom_out_cb) },
+  { "Zoom100",	GTK_STOCK_ZOOM_100,	N_("Zoom _1:1"),	"Z",		NULL,	CB(layout_menu_zoom_1_1_cb) },
+  { "ZoomFit",	GTK_STOCK_ZOOM_FIT,	N_("_Zoom to fit"),	"X",		NULL,	CB(layout_menu_zoom_fit_cb) },
+  { "FullScreen",	NULL,		N_("F_ull screen"),	"F",		NULL,	CB(layout_menu_fullscreen_cb) },
+  { "HideTools",	NULL,		N_("_Hide file list"),	"<control>H",	NULL,	CB(layout_menu_hide_cb) },
+  { "SlideShow",	NULL,		N_("Toggle _slideshow"),"S",		NULL,	CB(layout_menu_slideshow_cb) },
+  { "Refresh",	GTK_STOCK_REFRESH,	N_("_Refresh"),		"R",		NULL,	CB(layout_menu_refresh_cb) },
 
-	{ N_("/View/sep3"),			NULL,		NULL,				0, "<Separator>" },
-	{ N_("/View/_Float file list"),		"L",		layout_menu_float_cb,		0, "<CheckItem>" },
-	{ N_("/View/_Hide file list"),		"<control>H",	layout_menu_hide_cb,		0, NULL },
-	{ N_("/View/Hide tool_bar"),		NULL,		layout_menu_toolbar_cb,		0, "<CheckItem>" },
-	{ N_("/View/sep4"),			NULL,		NULL,				0, "<Separator>" },
-	{ N_("/View/_Keywords"),		"<control>K",	layout_menu_bar_info_cb,	0, "<CheckItem>" },
-	{ N_("/View/E_xif data"),		"<control>E",	layout_menu_bar_exif_cb,	0, "<CheckItem>" },
-	{ N_("/View/Sort _manager"),		"<control>S",	layout_menu_bar_sort_cb,	0, "<CheckItem>" },
-	{ N_("/View/sep5"),			NULL,		NULL,				0, "<Separator>" },
-	{ N_("/View/Toggle _slideshow"),	"S",		layout_menu_slideshow_cb,	0, NULL },
-	{ N_("/View/_Refresh Lists"),		"R",		layout_menu_refresh_cb,		0, "<StockItem>", GTK_STOCK_REFRESH },
-
-	{ N_("/_Help"),				NULL,		NULL,				0, "<Branch>" },
-	{ N_("/Help/tear1"),			NULL,		NULL,				0, "<Tearoff>" },
-	{ N_("/Help/_Contents"),		"F1",		layout_menu_help_cb,		0, "<StockItem>", GTK_STOCK_HELP },
-	{ N_("/Help/_Keyboard shortcuts"),	NULL,		layout_menu_help_keys_cb,	0, NULL },
-	{ N_("/Help/_Release notes"),		NULL,		layout_menu_notes_cb,		0, NULL },
-	{ N_("/Help/sep1"),			NULL,		NULL,				0, "<Separator>" },
-	{ N_("/Help/_About"),			NULL,		layout_menu_about_cb,		0, NULL },
+  { "HelpContents",	GTK_STOCK_HELP,	N_("_Contents"),	"F1",		NULL,	CB(layout_menu_help_cb) },
+  { "HelpShortcuts",	NULL,		N_("_Keyboard shortcuts"),NULL,		NULL,	CB(layout_menu_help_keys_cb) },
+  { "HelpNotes",	NULL,		N_("_Release notes"),	NULL,		NULL,	CB(layout_menu_notes_cb) },
+  { "About",		NULL,		N_("_About"),		NULL,		NULL,	CB(layout_menu_about_cb) }
 };
 
-static int gqview_nmenu_items = sizeof (gqview_menu_items) / sizeof (gqview_menu_items[0]);
+static GtkToggleActionEntry menu_toggle_entries[] = {
+  { "Thumbnails",	NULL,		N_("_Thumbnails"),	"T",		NULL,	CB(layout_menu_thumb_cb) },
+  { "FolderTree",	NULL,		N_("Tr_ee"),		"<control>T",	NULL,	CB(layout_menu_tree_cb) },
+  { "FloatTools",	NULL,		N_("_Float file list"),	"L",		NULL,	CB(layout_menu_float_cb) },
+  { "HideToolbar",	NULL,		N_("Hide tool_bar"),	NULL,		NULL,	CB(layout_menu_toolbar_cb) },
+  { "SBarKeywords",	NULL,		N_("_Keywords"),	"<control>K",	NULL,	CB(layout_menu_bar_info_cb) },
+  { "SBarExif",		NULL,		N_("E_xif data"),	"<control>E",	NULL,	CB(layout_menu_bar_exif_cb) },
+  { "SBarSort",		NULL,		N_("Sort _manager"),	"<control>S",	NULL,	CB(layout_menu_bar_sort_cb) }
+};
+
+static GtkRadioActionEntry menu_radio_entries[] = {
+  { "ViewList",		NULL,		N_("_List"),		"<control>L",	NULL,	0 },
+  { "ViewIcons",	NULL,		N_("I_cons"),		"<control>I",	NULL,	1 }
+};
+
+#undef CB
+
+static const char *menu_ui_description =
+"<ui>"
+"  <menubar name='MainMenu'>"
+"    <menu action='FileMenu'>"
+"      <menuitem action='NewWindow'/>"
+"      <menuitem action='NewCollection'/>"
+"      <menuitem action='OpenCollection'/>"
+"      <menuitem action='OpenRecent'/>"
+"      <separator/>"
+"      <menuitem action='Search'/>"
+"      <menuitem action='FindDupes'/>"
+"      <separator/>"
+"      <menuitem action='Print'/>"
+"      <menuitem action='NewFolder'/>"
+"      <separator/>"
+"      <menuitem action='Copy'/>"
+"      <menuitem action='Move'/>"
+"      <menuitem action='Rename'/>"
+"      <menuitem action='Delete'/>"
+"      <separator/>"
+"      <menuitem action='CloseWindow'/>"
+"      <menuitem action='Quit'/>"
+"    </menu>"
+"    <menu action='EditMenu'>"
+"      <menuitem action='Editor0'/>"
+"      <menuitem action='Editor1'/>"
+"      <menuitem action='Editor2'/>"
+"      <menuitem action='Editor3'/>"
+"      <menuitem action='Editor4'/>"
+"      <menuitem action='Editor5'/>"
+"      <menuitem action='Editor6'/>"
+"      <menuitem action='Editor7'/>"
+"      <menuitem action='Editor8'/>"
+"      <menuitem action='Editor9'/>"
+"      <separator/>"
+"      <menu action='AdjustMenu'>"
+"        <menuitem action='RotateCW'/>"
+"        <menuitem action='RotateCCW'/>"
+"        <menuitem action='Rotate180'/>"
+"        <menuitem action='Mirror'/>"
+"        <menuitem action='Flip'/>"
+"      </menu>"
+"      <menuitem action='Properties'/>"
+"      <separator/>"
+"      <menuitem action='SelectAll'/>"
+"      <menuitem action='SelectNone'/>"
+"      <separator/>"
+"      <menuitem action='Preferences'/>"
+"      <menuitem action='Maintenance'/>"
+"      <separator/>"
+"      <menuitem action='Wallpaper'/>"
+"    </menu>"
+"    <menu action='ViewMenu'>"
+"      <separator/>"
+"      <menuitem action='ZoomIn'/>"
+"      <menuitem action='ZoomOut'/>"
+"      <menuitem action='Zoom100'/>"
+"      <menuitem action='ZoomFit'/>"
+"      <separator/>"
+"      <menuitem action='Thumbnails'/>"
+"      <menuitem action='ViewList'/>"
+"      <menuitem action='ViewIcons'/>"
+"      <separator/>"
+"      <menuitem action='FolderTree'/>"
+"      <menuitem action='FullScreen'/>"
+"      <separator/>"
+"      <menuitem action='FloatTools'/>"
+"      <menuitem action='HideTools'/>"
+"      <menuitem action='HideToolbar'/>"
+"      <separator/>"
+"      <menuitem action='SBarKeywords'/>"
+"      <menuitem action='SBarExif'/>"
+"      <menuitem action='SBarSort'/>"
+"      <separator/>"
+"      <menuitem action='SlideShow'/>"
+"      <menuitem action='Refresh'/>"
+"    </menu>"
+"    <menu action='HelpMenu'>"
+"      <separator/>"
+"      <menuitem action='HelpContents'/>"
+"      <menuitem action='HelpShortcuts'/>"
+"      <menuitem action='HelpNotes'/>"
+"      <separator/>"
+"      <menuitem action='About'/>"
+"    </menu>"
+"  </menubar>"
+"</ui>";
+
 
 static gchar *menu_translate(const gchar *path, gpointer data)
 {
 	return _(path);
 }
 
-GtkWidget *layout_menu_bar(LayoutWindow *lw)
+void layout_actions_setup(LayoutWindow *lw)
 {
-	lw->menu_fact = gtk_item_factory_new(GTK_TYPE_MENU_BAR, "<main>", lw->accel_grp);
-	gtk_item_factory_set_translate_func(lw->menu_fact, menu_translate, NULL, NULL);
+	GError *error;
 
-	gtk_item_factory_create_items(lw->menu_fact, gqview_nmenu_items, gqview_menu_items, lw);
+	if (lw->ui_manager) return;
 
-	return gtk_item_factory_get_widget(lw->menu_fact, "<main>");
+	lw->action_group = gtk_action_group_new ("MenuActions");
+	gtk_action_group_set_translate_func(lw->action_group, menu_translate, NULL, NULL);
+
+	gtk_action_group_add_actions(lw->action_group,
+				     menu_entries, G_N_ELEMENTS(menu_entries), lw);
+	gtk_action_group_add_toggle_actions(lw->action_group,
+					    menu_toggle_entries, G_N_ELEMENTS(menu_toggle_entries), lw);
+	gtk_action_group_add_radio_actions(lw->action_group,
+					   menu_radio_entries, G_N_ELEMENTS(menu_radio_entries),
+					   0, G_CALLBACK(layout_menu_list_cb), lw);
+
+	lw->ui_manager = gtk_ui_manager_new();
+	gtk_ui_manager_set_add_tearoffs(lw->ui_manager, TRUE);
+	gtk_ui_manager_insert_action_group(lw->ui_manager, lw->action_group, 0);
+
+	error = NULL;
+	if (!gtk_ui_manager_add_ui_from_string(lw->ui_manager, menu_ui_description, -1, &error))
+		{
+		g_message ("building menus failed: %s", error->message);
+		g_error_free (error);
+		exit (EXIT_FAILURE);
+		}
 }
 
+void layout_actions_add_window(LayoutWindow *lw, GtkWidget *window)
+{
+	GtkAccelGroup *group;
+
+	if (!lw->ui_manager) return;
+
+	group = gtk_ui_manager_get_accel_group(lw->ui_manager);
+	gtk_window_add_accel_group(GTK_WINDOW(window), group);
+}
+
+GtkWidget *layout_actions_menu_bar(LayoutWindow *lw)
+{
+	return gtk_ui_manager_get_widget(lw->ui_manager, "/MainMenu");
+}
+
+
 /*
  *-----------------------------------------------------------------------------
  * toolbar
@@ -989,53 +1109,41 @@ GtkWidget *layout_button_bar(LayoutWindow *lw)
 
 static void layout_util_sync_views(LayoutWindow *lw)
 {
-	GtkWidget *item;
+	GtkAction *action;
 
-	if (!lw->menu_fact) return;
+	if (!lw->action_group) return;
 
-	item = gtk_item_factory_get_item(lw->menu_fact, "/View/Tree");
-	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item), lw->tree_view);
+	action = gtk_action_group_get_action(lw->action_group, "FolderTree");
+	gtk_toggle_action_set_active(GTK_TOGGLE_ACTION(action), lw->tree_view);
 
-	item = gtk_item_factory_get_item(lw->menu_fact, "/View/Icons");
-	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item), lw->icon_view);
+	action = gtk_action_group_get_action(lw->action_group, "ViewIcons");
+	gtk_toggle_action_set_active(GTK_TOGGLE_ACTION(action), lw->icon_view);
 
-	item = gtk_item_factory_get_item(lw->menu_fact, "/View/Float file list");
-	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item), lw->tools_float);
+	action = gtk_action_group_get_action(lw->action_group, "FloatTools");
+	gtk_toggle_action_set_active(GTK_TOGGLE_ACTION(action), lw->tools_float);
 
-	item = gtk_item_factory_get_item(lw->menu_fact, "/View/Keywords");
-	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item), lw->bar_info_enabled);
+	action = gtk_action_group_get_action(lw->action_group, "SBarKeywords");
+	gtk_toggle_action_set_active(GTK_TOGGLE_ACTION(action), lw->bar_info_enabled);
 
-	item = gtk_item_factory_get_item(lw->menu_fact, "/View/Exif data");
-	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item), lw->bar_exif_enabled);
+	action = gtk_action_group_get_action(lw->action_group, "SBarExif");
+	gtk_toggle_action_set_active(GTK_TOGGLE_ACTION(action), lw->bar_exif_enabled);
 
-	item = gtk_item_factory_get_item(lw->menu_fact, "/View/Sort manager");
-	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item), lw->bar_sort_enabled);
+	action = gtk_action_group_get_action(lw->action_group, "SBarSort");
+	gtk_toggle_action_set_active(GTK_TOGGLE_ACTION(action), lw->bar_sort_enabled);
 
-	item = gtk_item_factory_get_item(lw->menu_fact, "/View/Hide toolbar");
-	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item), lw->toolbar_hidden);
+	action = gtk_action_group_get_action(lw->action_group, "HideToolbar");
+	gtk_toggle_action_set_active(GTK_TOGGLE_ACTION(action), lw->toolbar_hidden);
 }
 
 void layout_util_sync_thumb(LayoutWindow *lw)
 {
-	GtkWidget *item;
+	GtkAction *action;
 
-	if (lw->icon_view)
-		{
-		item = gtk_item_factory_get_item(lw->menu_fact, "/View/Icons");
-		}
-	else
-		{
-		item = gtk_item_factory_get_item(lw->menu_fact, "/View/List");
-		}
+	if (!lw->action_group) return;
 
-	if (!GTK_CHECK_MENU_ITEM(item)->active)
-		{
-		gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item), TRUE);
-		}
-
-	item = gtk_item_factory_get_item(lw->menu_fact, "/View/Thumbnails");
-	GTK_CHECK_MENU_ITEM(item)->active = lw->thumbs_enabled;
-	gtk_widget_set_sensitive(item, !lw->icon_view);
+	action = gtk_action_group_get_action(lw->action_group, "Thumbnails");
+	gtk_toggle_action_set_active(GTK_TOGGLE_ACTION(action), lw->thumbs_enabled);
+	g_object_set(action, "sensitive", !lw->icon_view, NULL);
 
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lw->thumb_button), lw->thumbs_enabled);
 	gtk_widget_set_sensitive(lw->thumb_button, !lw->icon_view);
@@ -1061,9 +1169,10 @@ PixmapFolders *folder_icons_new(void)
 
 	pf = g_new0(PixmapFolders, 1);
 
-	pf->close = gdk_pixbuf_new_from_xpm_data((const char **)folder_close_xpm);
-	pf->open = gdk_pixbuf_new_from_xpm_data((const char **)folder_open_xpm);
-	pf->deny = gdk_pixbuf_new_from_xpm_data((const char **)folder_deny_xpm);
+	pf->close = pixbuf_inline(PIXBUF_INLINE_FOLDER_CLOSED);
+	pf->open = pixbuf_inline(PIXBUF_INLINE_FOLDER_OPEN);
+	pf->deny = pixbuf_inline(PIXBUF_INLINE_FOLDER_LOCKED);
+	pf->parent = pixbuf_inline(PIXBUF_INLINE_FOLDER_UP);
 
 	return pf;
 }
@@ -1075,6 +1184,7 @@ void folder_icons_free(PixmapFolders *pf)
 	g_object_unref(pf->close);
 	g_object_unref(pf->open);
 	g_object_unref(pf->deny);
+	g_object_unref(pf->parent);
 
 	g_free(pf);
 }
@@ -1160,6 +1270,13 @@ static void layout_bar_info_new_selection(LayoutWindow *lw, gint count)
 	bar_info_selection(lw->bar_info, count - 1);
 }
 
+static void layout_bar_info_maint_renamed(LayoutWindow *lw)
+{
+	if (!lw->bar_info || !lw->bar_info_enabled) return;
+
+	bar_info_maint_renamed(lw->bar_info, layout_image_get_path(lw));
+}
+
 static void layout_bar_exif_destroyed(GtkWidget *widget, gpointer data)
 {
 	LayoutWindow *lw = data;
@@ -1299,7 +1416,7 @@ void layout_bars_new_selection(LayoutWindow *lw, gint count)
 
 GtkWidget *layout_bars_prepare(LayoutWindow *lw, GtkWidget *image)
 {
-	lw->utility_box = gtk_hbox_new(FALSE, 0);
+	lw->utility_box = gtk_hbox_new(FALSE, PREF_PAD_GAP);
 	gtk_box_pack_start(GTK_BOX(lw->utility_box), image, TRUE, TRUE, 0);
 	gtk_widget_show(image);
 
@@ -1328,3 +1445,8 @@ void layout_bars_close(LayoutWindow *lw)
 	layout_bar_info_close(lw);
 }
 
+void layout_bars_maint_renamed(LayoutWindow *lw)
+{
+	layout_bar_info_maint_renamed(lw);
+}
+
