@@ -26,7 +26,9 @@ void layout_edit_update_all(void);
 void layout_recent_update_all(void);
 void layout_recent_add_path(const gchar *path);
 
-GtkWidget *layout_menu_bar(LayoutWindow *lw);
+void layout_actions_setup(LayoutWindow *lw);
+void layout_actions_add_window(LayoutWindow *lw, GtkWidget *window);
+GtkWidget *layout_actions_menu_bar(LayoutWindow *lw);
 
 GtkWidget *layout_button(GtkWidget *box, gchar **pixmap_data, const gchar *stock_id, gint toggle,
 			 GtkTooltips *tooltips, const gchar *tip_text,
@@ -50,5 +52,7 @@ void layout_bars_new_selection(LayoutWindow *lw, gint count);
 GtkWidget *layout_bars_prepare(LayoutWindow *lw, GtkWidget *image);
 void layout_bars_close(LayoutWindow *lw);
 
+void layout_bars_maint_renamed(LayoutWindow *lw);
+
 
 #endif
