@@ -1,6 +1,6 @@
 /*
  * GQview
- * (C) 2004 John Ellis
+ * (C) 2006 John Ellis
  *
  * Author: John Ellis
  *
@@ -2200,7 +2200,7 @@ static void file_util_rename_multiple_do(GList *source_list, GtkWidget *parent)
 	box2 = furm_simple_vlabel(hbox, _("Start #"), FALSE);
 
 	rd->auto_spin_start = pref_spin_new(box2, NULL, NULL,
-					    0.0, 1000000.0, 1.0, 0, 0.0,
+					    1.0, 1000000.0, 1.0, 0, 0.0,
 					    G_CALLBACK(file_util_rename_multiple_preview_adj_cb), rd);
 
 	box2 = furm_simple_vlabel(hbox, _("End text"), TRUE);
@@ -2453,3 +2453,43 @@ void file_util_create_dir(const gchar *path, GtkWidget *parent)
 	gtk_widget_show(GENERIC_DIALOG(fd)->dialog);
 }
 
+gint file_util_rename_dir(const gchar *old_path, const gchar *new_path, GtkWidget *parent)
+{
+	const gchar *old_name;
+	const gchar *new_name;
+
+	if (!old_path || !new_path || !isdir(old_path)) return FALSE;
+
+	old_name = filename_from_path(old_path);
+	new_name = filename_from_path(new_path);
+
+	if (isdir(new_path))
+		{
+		gchar *text = g_strdup_printf(_("The folder:\n%s\nalready exists."), new_name);
+		file_util_warning_dialog(_("Folder exists"), text, GTK_STOCK_DIALOG_INFO, parent);
+		g_free(text);
+
+		return FALSE;
+		}
+
+	if (isname(new_path))
+		{
+		gchar *text = g_strdup_printf(_("The path:\n%s\nalready exists as a file."), new_name);
+		file_util_warning_dialog(_("Rename failed"), text, GTK_STOCK_DIALOG_INFO,parent);
+		g_free(text);
+
+		return FALSE;
+		}
+
+	if (!rename_file(old_path, new_path))
+		{
+		gchar *text = g_strdup_printf(_("Failed to rename %s to %s."), old_name, new_name);
+		file_util_warning_dialog(_("Rename failed"), text, GTK_STOCK_DIALOG_ERROR, parent);
+		g_free(text);
+
+		return FALSE;
+		}
+
+	return TRUE;
+}
+
